<?php
/**
 * mr language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesMr.php?view=co
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '`';
$lang['singlequoteclosing']    = '\'';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'हे पृष्ठ संपादित करा';
$lang['btn_source']            = 'पानाचा स्त्रोत दाखवा ';
$lang['btn_show']              = 'पान दाखवा';
$lang['btn_create']            = 'हे पृष्ठ लीहा';
$lang['btn_search']            = 'शोधा';
$lang['btn_save']              = 'सुरक्षित';
$lang['btn_preview']           = 'झलक';
$lang['btn_top']               = 'परत वर';
$lang['btn_newer']             = 'जास्त अलीकडचे';
$lang['btn_older']             = 'कमी अलीकडचे';
$lang['btn_revs']              = 'जून्या आव्रुत्ती';
$lang['btn_recent']            = 'अलीकडील बदल';
$lang['btn_upload']            = 'अपलोड';
$lang['btn_cancel']            = 'रद्द करा';
$lang['btn_index']             = 'सूचि';
$lang['btn_secedit']           = 'संपादन';
$lang['btn_login']             = 'प्रवेश करा';
$lang['btn_logout']            = 'बाहेर पडा';
$lang['btn_admin']             = 'अधिकारी';
$lang['btn_update']            = 'अद्ययावत';
$lang['btn_delete']            = 'नष्ट';
$lang['btn_back']              = 'मागॆ';
$lang['btn_backlink']          = 'येथे काय जोडले आहे';
$lang['btn_backtomedia']       = 'परत माध्यम फाइल निवडीकड़े';
$lang['btn_subscribe']         = 'पृष्ठाच्या बदलांची पुरवणी (फीड) लावा ';
$lang['btn_profile']           = 'प्रोफाइल अद्ययावत करा';
$lang['btn_reset']             = 'रिसेट';
$lang['btn_resendpwd']         = 'नवीन पासवर्ड';
$lang['btn_draft']             = 'प्रत संपादन';
$lang['btn_recover']           = 'प्रत परत मिळवा';
$lang['btn_draftdel']          = 'प्रत रद्द';
$lang['btn_revert']            = 'पुनर्स्थापन';
$lang['btn_register']          = 'नोंदणी';
$lang['btn_apply']             = 'लागू';
$lang['btn_media']             = 'मिडिया व्यवस्थापक';
$lang['loggedinas']            = 'लॉगिन नाव';
$lang['user']                  = 'वापरकर्ता';
$lang['pass']                  = 'परवलीचा शब्द';
$lang['newpass']               = 'नवीन परवलीचा शब्द';
$lang['oldpass']               = 'सध्याचा परवलीचा शब्द नक्की करा';
$lang['passchk']               = 'परत एकदा';
$lang['remember']              = 'लक्षात ठेवा';
$lang['fullname']              = 'पूर्ण नावं';
$lang['email']                 = 'इमेल';
$lang['profile']               = 'वापरकर्त्याची माहिती';
$lang['badlogin']              = 'माफ़ करा, वापरकर्ता नावात किंवा परवलीच्या शब्दात चूक झाली आहे.';
$lang['minoredit']             = 'छोटे बदल';
$lang['draftdate']             = 'प्रत आपोआप सुरक्षित केल्याची तारीख';
$lang['nosecedit']             = 'मध्यंतरीच्या काळात हे पृष्ठ बदलले आहे.विभागाची माहिती जुनी झाली होती. त्याऐवजी सबंध पृष्ठ परत लोड केले आहे.';
$lang['regmissing']            = 'कृपया सर्व रकाने भरा.';
$lang['reguexists']            = 'या नावाने सदस्याची नोंदणी झालेली आहे, कृपया दुसरे सदस्य नाव निवडा.';
$lang['regsuccess']            = 'सदस्याची नोंदणी झाली आहे आणि परवलीचा शब्द इमेल केला आहे.';
$lang['regsuccess2']           = 'सदस्याची नोंदणी झाली.';
$lang['regmailfail']           = 'परवलीचा शब्दाची इमेल पाठवण्यात चूक झाली आहे, क्रुपया संचालकांशी संपर्क साधा.';
$lang['regbadmail']            = 'तुम्ही दिलेला ईमेल बरोबर नाही असे दिसते - तुमच्या मते ही चूक असल्यास साईटच्या व्यवस्थापकाशी संपर्क साधा.';
$lang['regbadpass']            = 'आपला परवलीचा शब्द चुकीचा आहे.';
$lang['regpwmail']             = 'तुमचा डोक्युविकि परवली.';
$lang['reghere']               = 'अजुन तुमचे खाते नाही ? एक उघडून टाका.';
$lang['profna']                = 'ह्या विकी मधे प्रोफाइल बदलण्याची सुविधा नाही.';
$lang['profnochange']          = 'काही बदल नाहित. करण्यासारखे काही नाही.';
$lang['profnoempty']           = 'रिकामे नाव किंवा ईमेल चालत नाही.';
$lang['profchanged']           = 'सदस्याची प्रोफाइल अद्ययावत झाली आहे.';
$lang['pwdforget']             = 'परवलीचा शब्द विसरला आहे का? नविन मागवा.';
$lang['resendna']              = 'ह्या विकी मधे परवलीचा शब्द परत पाथाव्न्याची सुविधा नाही.';
$lang['resendpwd']             = 'नविन परवली इच्छुक';
$lang['resendpwdmissing']      = 'माफ करा, पण सर्व जागा भरल्या पाहिजेत.';
$lang['resendpwdnouser']       = 'माफ़ करा, हा सदस्य आमच्या माहितिसंग्रहात सापडला नाही.';
$lang['resendpwdbadauth']      = 'माफ़ करा, हा अधिकार कोड बरोबर नाही. कृपया आपण पूर्ण शिकामोर्तबाची लिंक वापरल्याची खात्री करा.';
$lang['resendpwdconfirm']      = 'शिक्कामोर्तबाची लिंक ईमेल द्वारा पाठवली आहे.';
$lang['resendpwdsuccess']      = 'शिक्कामोर्तबाची लिंक ईमेल द्वारा पाठवली आहे.';
$lang['license']               = 'विशिष्ठ नोंद केलि नसल्यास ह्या विकी वरील सर्व मजकूर खालील लायसन्स मधे मोडतो : ';
$lang['licenseok']             = 'नोंद : हे पृष्ठ संपादित केल्यास तुम्ही तुमचे योगदान खालील लायसन्स अंतर्गत येइल : ';
$lang['searchmedia']           = 'फाईल शोधा:';
$lang['searchmedia_in']        = '%s मधे शोधा';
$lang['txt_upload']            = 'अपलोड करण्याची फाइल निवडा';
$lang['txt_filename']          = 'अपलोड उर्फ़ ( वैकल्पिक )';
$lang['txt_overwrt']           = 'अस्तित्वात असलेल्या फाइलवरच सुरक्षित करा.';
$lang['lockedby']              = 'सध्या लॉक करणारा :';
$lang['lockexpire']            = 'सध्या लॉक करणारा :';
$lang['js']['willexpire']      = 'हे पृष्ठ संपादित करण्यासाठी मिळालेले लॉक एखाद्या मिनिटात संपणार आहे.\n चुका होऊ नयेत म्हणुन कृपया प्रीव्यू बटन दाबुन लॉक ची वेळ पुन्हा चालू करा.';
$lang['js']['notsavedyet']     = 'सुरक्षित न केलेले बदल नष्ट होतील. नक्की करू का ?';
$lang['js']['searchmedia']     = 'फाईल्ससाठी शोधा';
$lang['js']['keepopen']        = 'निवड केल्यावर विण्डो उघडी ठेवा';
$lang['js']['hidedetails']     = 'सविस्तर मजकूर लपवा';
$lang['js']['mediatitle']      = 'लिंक सेटिंग';
$lang['js']['mediadisplay']    = 'लिंकचा प्रकार';
$lang['js']['mediaalign']      = 'जुळवणी';
$lang['js']['mediasize']       = 'प्रतिमेचा आकार';
$lang['js']['mediatarget']     = 'लिंकचे लक्ष्य';
$lang['js']['mediaclose']      = 'बंद';
$lang['js']['mediadisplayimg'] = 'प्रतिमा दाखवा.';
$lang['js']['mediadisplaylnk'] = 'फक्त लिंक दाखवा.';
$lang['js']['mediasmall']      = 'लहान आवृत्ती';
$lang['js']['mediamedium']     = 'माध्यम आवृत्ती';
$lang['js']['medialarge']      = 'मोठी आवृत्ती';
$lang['js']['mediaoriginal']   = 'मूळ आवृत्ती';
$lang['js']['medialnk']        = 'सविस्तर माहितीकडेची लिंक';
$lang['js']['mediadirect']     = 'मूळ मजकुराकडे थेट लिंक';
$lang['js']['medianolnk']      = 'लिंक नको';
$lang['js']['medianolink']     = 'प्रतिमा लिंक करू नका';
$lang['js']['medialeft']       = 'प्रतिमा डाव्या बाजूला जुळवून घ्या.';
$lang['js']['mediaright']      = 'प्रतिमा उजव्या बाजूला जुळवून घ्या.';
$lang['js']['mediacenter']     = 'प्रतिमा मध्यभागी जुळवून घ्या.';
$lang['js']['medianoalign']    = 'जुळवाजुळव वापरू नका.';
$lang['js']['nosmblinks']      = 'विन्डोज़ शेअर ला लिंक केल्यास ते फक्त मायक्रोसॉफ़्ट इन्टरनेट एक्स्प्लोरर वरच चालते. तरी तुम्ही लिंक कॉपी करू शकता.';
$lang['js']['linkwiz']         = 'लिंक जादूगार';
$lang['js']['linkto']          = 'याला लिंक करा:';
$lang['js']['del_confirm']     = 'निवडलेल्या गोष्टी नक्की नष्ट करू का ?';
$lang['js']['restore_confirm'] = 'हि आवृत्ती खरोखर पुनर्स्थापित करू का?';
$lang['js']['media_diff']      = 'फरक बघू:';
$lang['js']['media_diff_both'] = 'बाजूबाजूला';
$lang['js']['media_diff_portions'] = 'स्वाईप';
$lang['js']['media_select']    = 'फाईल निवड...';
$lang['js']['media_upload_btn'] = 'अपलोड';
$lang['js']['media_done_btn']  = 'झालं';
$lang['js']['media_drop']      = 'अपलोड करण्यासाठी इथे फाईल टाका';
$lang['js']['media_cancel']    = 'काढा';
$lang['rssfailed']             = 'ही पुरवणी आणण्यात काही चूक झाली:';
$lang['nothingfound']          = 'काही सापडला नाही.';
$lang['mediaselect']           = 'दृकश्राव्य फाइल';
$lang['fileupload']            = 'दृकश्राव्य फाइल अपलोड';
$lang['uploadsucc']            = 'अपलोड यशस्वी';
$lang['uploadfail']            = 'अपलोड अयशस्वी.कदाचित चुकीच्या परवानग्या असतील ?';
$lang['uploadwrong']           = 'अपलोड नाकारण्यात आला. हे फाइल एक्सटेंशन अवैध आहे!';
$lang['uploadexist']           = 'फाइल आधीच अस्तित्वात आहे. काही केले नाही.';
$lang['uploadbadcontent']      = 'अपलोड केलेली माहिती %s फाइल एक्सटेंशनशी मिळतिजुळति नाही.';
$lang['uploadspam']            = 'अपलोड स्पॅम ब्लॅकलिस्टमुळे थोपवला आहे.';
$lang['uploadxss']             = 'अपलोड संशयित हानिकारक मजकूर असल्याने थोपवला आहे.';
$lang['uploadsize']            = 'अपलोड केलेली फाइल जास्तीच मोठी होती. (जास्तीत जास्त %s)';
$lang['deletesucc']            = '%s ही फाइल नष्ट करण्यात आलेली आहे.';
$lang['deletefail']            = '%s ही फाइल नष्ट करू शकलो नाही - कृपया परवानग्या तपासा.';
$lang['mediainuse']            = '%s ही फाइल नष्ट केली नाही - ती अजुन वापरात आहे.';
$lang['namespaces']            = 'नेमस्पेस';
$lang['mediafiles']            = 'मध्ये उपलब्ध असलेल्या फाइल';
$lang['accessdenied']          = 'तुम्हाला हे पान बघायची परवानगी नाही.';
$lang['mediausage']            = 'ह्या फाइलचा संदर्भ देण्यासाठी खालील सिन्टॅक्स वापरा :';
$lang['mediaview']             = 'मूळ फाइल बघू ';
$lang['mediaroot']             = 'रूट';
$lang['mediaupload']           = 'सध्याच्या नेमस्पेसमधे इथेच फाइल अपलोड करा. उप-नेमस्पेस बनवण्यासाठि त्याचे नाव तुमच्या "अपलोड उर्फ़" मधे दिलेल्या फाइल नावाच्या आधी विसर्गचिन्हाने वेगळे करून ते वापरा.';
$lang['mediaextchange']        = 'फाइलचे एक्सटेंशन .%s चे बदलून  .%s केले आहे.';
$lang['reference']             = 'च्या साठी संदर्भ';
$lang['ref_inuse']             = 'फाइल नष्ट केली जाऊ शकत नाही. ती अजुन खालील पृष्ठे वापरत आहेत :';
$lang['ref_hidden']            = 'काही संदर्भ तुम्हाला वाचण्याची परवानगी नसलेल्या पृष्ठावर आहेत';
$lang['hits']                  = 'हिट्स';
$lang['quickhits']             = 'जुळणारि पाने';
$lang['toc']                   = 'अनुक्रमणिका';
$lang['current']               = 'चालू';
$lang['yours']                 = 'तुमची आवृत्ति';
$lang['diff']                  = 'सध्याच्या आवृत्तिंशी फरक दाखवा';
$lang['diff2']                 = 'निवडलेल्या आवृत्तिंमधील फरक दाखवा';
$lang['difflink']              = 'ह्या तुलना दृष्टीकोनाला लिंक करा';
$lang['diff_type']             = 'फरक बघू:';
$lang['diff_inline']           = 'एका ओळीत';
$lang['diff_side']             = 'बाजूबाजूला';
$lang['line']                  = 'ओळ';
$lang['breadcrumb']            = 'मागमूस';
$lang['youarehere']            = 'तुम्ही इथे आहात';
$lang['lastmod']               = 'सर्वात शेवटचा बदल';
$lang['by']                    = 'द्वारा';
$lang['deleted']               = 'काढून टाकले';
$lang['created']               = 'निर्माण केले';
$lang['restored']              = 'जुनी आवृत्ति पुनर्स्थापित केली';
$lang['external_edit']         = 'बाहेरून संपादित';
$lang['summary']               = 'सारांश बदला';
$lang['noflash']               = 'ही माहिती दाखवण्यासाठी <a href="http://www.adobe.com/products/flashplayer/">अडोब फ्लॅश प्लेअर</a> ची गरज आहे.';
$lang['download']              = 'तुकडा डाउनलोड करा';
$lang['tools']                 = 'साधने';
$lang['user_tools']            = 'युजरची साधने';
$lang['site_tools']            = 'साईटची साधने';
$lang['page_tools']            = 'पानाची साधने';
$lang['skip_to_content']       = 'सरळ मजकुराकडे ';
$lang['mail_newpage']          = 'पृष्ठ जोडले : ';
$lang['mail_changed']          = 'पृष्ठ बदलले : ';
$lang['mail_subscribe_list']   = 'ह्या नेमस्पेस नाढे बदललेली पाने:';
$lang['mail_new_user']         = 'नवीन सदस्य : ';
$lang['mail_upload']           = 'फाइल अपलोड केली : ';
$lang['changes_type']          = 'ह्याचे बदल बघू';
$lang['pages_changes']         = 'पाने';
$lang['media_changes']         = 'मिडिया फाईल';
$lang['both_changes']          = 'पाने आणि मिडिया फाईल दोन्ही';
$lang['qb_bold']               = 'ठळक मजकूर';
$lang['qb_italic']             = 'तिरका मजकूर';
$lang['qb_underl']             = 'अधोरेखित मजकूर';
$lang['qb_code']               = 'कोड मजकूर';
$lang['qb_strike']             = 'रद्द मजकूर';
$lang['qb_h1']                 = 'पहिल्या पातळीचे शीर्षक';
$lang['qb_h2']                 = 'दुसर्या पातळीचे शीर्षक';
$lang['qb_h3']                 = 'तिसर्या पातळीचे शीर्षक';
$lang['qb_h4']                 = 'चवथ्या पातळीचे शीर्षक';
$lang['qb_h5']                 = 'पाचव्या पातळीचे शीर्षक';
$lang['qb_h']                  = 'शीर्षक';
$lang['qb_hs']                 = 'शीर्षक निवड';
$lang['qb_hplus']              = 'उंच शीर्षक';
$lang['qb_hminus']             = 'खालचं शीर्षक';
$lang['qb_hequal']             = 'समान लेवलचे शीर्षक';
$lang['qb_link']               = 'अंतर्गत लिंक';
$lang['qb_extlink']            = 'बाह्य लिंक';
$lang['qb_hr']                 = 'आडवी पट्टी';
$lang['qb_ol']                 = 'अनुक्रमित यादीतील वस्तु';
$lang['qb_ul']                 = 'साध्या यादीतील वस्तु';
$lang['qb_media']              = 'प्रतिमा आणि इतर फाइल टाका';
$lang['qb_sig']                = 'स्वाक्षरी टाका';
$lang['qb_smileys']            = 'स्माइली';
$lang['qb_chars']              = 'ख़ास चिन्ह';
$lang['upperns']               = 'ह्यावरच्या नेमस्पेसकडे उडी मारा';
$lang['admin_register']        = 'नवीन सदस्य';
$lang['metaedit']              = 'मेटाडेटा बदला';
$lang['metasaveerr']           = 'मेटाडेटा सुरक्षित झाला नाही';
$lang['metasaveok']            = 'मेटाडेटा सुरक्षित झाला';
$lang['img_backto']            = 'परत जा';
$lang['img_title']             = 'नाव';
$lang['img_caption']           = 'टीप';
$lang['img_date']              = 'तारीख';
$lang['img_fname']             = 'फाइल नाव';
$lang['img_fsize']             = 'साइझ';
$lang['img_artist']            = 'फोटोग्राफर';
$lang['img_copyr']             = 'कॉपीराइट';
$lang['img_format']            = 'प्रकार';
$lang['img_camera']            = 'कॅमेरा';
$lang['img_keywords']          = 'मुख्य शब्द';
$lang['img_width']             = 'रुंदी';
$lang['img_height']            = 'उंची';
$lang['img_manager']           = 'मिडिया व्यवस्थापकात बघू';
$lang['authmodfailed']         = 'सदस्य अधिकृत करण्याची व्यवस्था चुकीची आहे. कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
$lang['authtempfail']          = 'सदस्य अधिकृत करण्याची सुविधा सध्या चालू नाही. सतत हा मजकूर दिसल्यास कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
$lang['i_chooselang']          = 'तुमची भाषा निवडा';
$lang['i_installer']           = 'डॉक्युविकि इनस्टॉलर';
$lang['i_wikiname']            = 'विकी नाम';
$lang['i_enableacl']           = 'ACL चालू करा ( अधिक चांगले )';
$lang['i_superuser']           = 'सुपर-सदस्य';
$lang['i_problems']            = 'इनस्टॉलरला काही अडचणि आल्या आहेत. त्या ठीक केल्याशिवाय तुम्ही पुढे जाऊ शकत नाही.';
$lang['i_modified']            = 'सुरक्षिततेच्या कारणासठि ही स्क्रिप्ट फ़क्त नवीन आणि बदललेल्या डॉक्युविकि इन्स्टॉलेशन मधेच चालेल. तुम्ही एकतर डाउनलोड केलेले पॅकेज मधील फाइल परत प्रसारित करा किंवा <a href="http://dokuwiki.org/install">डॉक्युविकि इन्स्टॉलेशन विषयी सूचना</a> वाचा.';
$lang['i_funcna']              = 'PHP  मधलं <code>%s</code> हे फंक्शन उपलब्ध नाही. बहुधा तुमच्या होस्टिंग पुरवणाराने ते काही कारणाने अनुपलब्ध केलं असावं.';
$lang['i_phpver']              = 'तुमची PHP आवृत्ति <code>%s</code> ही आवश्यक असलेल्या <code>%s</code> ह्या आवृत्तिपेक्षा कमी आहे. कृपया तुमचे PHP इन्स्टॉलेशन अद्ययावत करा.';
$lang['i_permfail']            = '<code>%s</code> या डिरेक्टरी मध्ये डॉक्युविकि बदल करू शकत नाही. कृपया या डिरेक्टरीच्या परवानग्या ठीक करा.';
$lang['i_confexists']          = '<code>%s</code> आधीच अस्तित्वात आहे.';
$lang['i_writeerr']            = '<code>%s</code> निर्माण करू शकलो नाही. तुम्हाला डिरेक्टरी / फाइल च्या परवानग्या तपासून स्वतःच ही फाइल बनवावी लागेल.';
$lang['i_badhash']             = 'अनाकलनीय किंवा बदललेले dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = 'code>%s</code> - अवैध किंवा रिकामा मजकूर.';
$lang['i_success']             = 'व्यवस्था लावण्याचे काम यशस्वीरीत्या पार पडले. आता तुम्ही install.php डिलीट करू शकता. <a href="doku.php">तुमच्या नविन डॉक्युविकि </a> वर जा.';
$lang['i_failure']             = 'कॉन्फिगुरेशनच्या फाइल सुरक्षित करताना काही अडचणी आल्या आहेत. <a href="doku.php">तुमची नवीन डॉक्युविकि </a> वापरण्याआधी तुम्हाला ह्या फाइल स्वतः ठीक कराव्या लागतील.';
$lang['i_policy']              = 'आरंभीची ACL पॉलिसी';
$lang['i_pol0']                = 'मुक्त विकी ( सर्वांना वाचन, लेखन व अपलोड करण्याची परवानगी )';
$lang['i_pol1']                = 'सार्वजनिक विकी ( सर्वांना वाचण्याची मुभा , लेखन व अपलोडची परवानगी फक्त नोंदणीकृत सदस्यांना )';
$lang['i_pol2']                = 'बंदिस्त विकी ( वाचन , लेखन व अपलोडची परवानगी फक्त नोंदणीकृत सदस्यांना ) ';
$lang['i_retry']               = 'पुन्हा प्रयत्न';
$lang['recent_global']         = 'तुम्ही सध्या <b>%s</b> या नेमस्पेस मधील बदल पाहात आहात.तुम्ही <a href="%s">पूर्ण विकी मधले बदल </a> सुद्धा पाहू शकता.';
